@@ -1,19 +1,17 @@
 
-#' @importFrom cli get_spinner cli_status
-
 create_progress_bar <- function(data) {
   bar <- new.env(parent = emptyenv())
 
   if (isTRUE(getOption("pkg.show_progress", FALSE))) {
-    bar$status <- cli_status(
+    bar$status <- cli::cli_status(
       "Checking for {nrow(data)} new metadata file{?s}",
       .auto_close = FALSE
     )
   } else {
-    bar$status <- cli_status(character(), .auto_close = FALSE)
+    bar$status <- cli::cli_status(character(), .auto_close = FALSE)
   }
 
-  bar$spinner <- get_spinner()
+  bar$spinner <- cli::get_spinner()
   bar$spinner_state <- 1L
 
   bar$data <- data
@@ -52,9 +50,6 @@ update_progress_bar_done  <- function(bar, url) {
     file.size(bar$data$path[[wh]])
 }
 
-#' @importFrom prettyunits pretty_bytes
-#' @importFrom cli cli_status_update
-
 show_progress_bar <- function(bar) {
   if (is.null(bar$status) ||
     !isTRUE(getOption("pkg.show_progress", FALSE))) {
@@ -67,7 +62,9 @@ show_progress_bar <- function(bar) {
   current <- sum(data$current, na.rm = TRUE)
   total <- sum(data$size, na.rm = TRUE)
   downloads <- paste0(
-    "[", pretty_bytes(current), " / ", pretty_bytes(total), "]")
+    "[", format_bytes$pretty_bytes(current), " / ",
+    format_bytes$pretty_bytes(total), "]"
+  )
 
   spinner <- bar$spinner$frames[bar$spinner_state]
   bar$spinner_state <- bar$spinner_state + 1L
@@ -75,18 +72,16 @@ show_progress_bar <- function(bar) {
     bar$spinner_state <- 1L
   }
 
-  cli_status_update(
+  cli::cli_status_update(
     bar$status,
     c("{spinner} Updating metadata database [{uptodate}/{numfiles}] | ",
       "Downloading {downloads}")
   )
 }
 
-#' @importFrom cli cli_status_clear
-
 finish_progress_bar <- function(ok, bar) {
   if (!ok) {
-    cli_status_clear(
+    cli::cli_status_clear(
       bar$status,
       result = "failed",
       msg_failed = "{.alert-danger Metadata update failed}"
@@ -95,15 +90,15 @@ finish_progress_bar <- function(ok, bar) {
   } else if (FALSE %in% bar$data$uptodate) {
     dl <- vlapply(bar$data$uptodate, identical, FALSE)
     files <- sum(dl)
-    bytes <- pretty_bytes(sum(bar$data$size[dl], na.rm = TRUE))
-    cli_status_clear(
+    bytes <- format_bytes$pretty_bytes(sum(bar$data$size[dl], na.rm = TRUE))
+    cli::cli_status_clear(
       bar$status,
       result = "done",
       msg_done = "{.alert-success Updated metadata database: {bytes} in {files} file{?s}.}"
     )
 
   } else {
-    cli_status_clear(bar$status)
+    cli::cli_status_clear(bar$status)
   }
 
   bar$status <- NULL
