@@ -59,12 +59,9 @@ repo_get <- function(r_version = getRversion(), bioc = TRUE,
 #'
 #' @export
 #' @examplesIf pkgcache:::run_examples()
-#' repo_resolve("MRAN@2020-01-21")
-#' repo_resolve("PPM@2020-01-21")
-#' repo_resolve("MRAN@dplyr-1.0.0")
-#' repo_resolve("PPM@dplyr-1.0.0")
-#' repo_resolve("MRAN@R-4.0.0")
-#' repo_resolve("PPM@R-4.0.0")
+#' repo_resolve("PPM@2021-01-21")
+#' #' repo_resolve("PPM@dplyr-1.0.0")
+#' #' repo_resolve("PPM@R-4.0.0")
 
 repo_resolve <- function(spec) {
   repo_sugar(spec, names(spec))
@@ -187,13 +184,13 @@ repo_sugar_path <- function(x, nm) {
 repo_sugar_mran <- function(x, nm) {
   if (is.null(nm) || nm == "") nm <- "CRAN"
   date <- parse_spec(sub("^MRAN@", "", x))
-  if (date < "2015-02-01") {
-    stop("MRAN snapshots go back to 2015-02-01 only")
+  if (date < "2017-10-10") {
+    stop("PPM snapshots go back to 2017-10-10 only")
   }
 
   mran <- Sys.getenv(
     "PKGCACHE_MRAN_URL",
-    "https://cran.microsoft.com/snapshot"
+    "https://packagemanager.posit.co/cran"
   )
   structure(paste0(mran, "/", date), names = nm)
 }
@@ -214,7 +211,7 @@ repo_sugar_ppm <- function(x, nm) {
 
   # if we may have binaries, then get the distro data as well
   synchronise(when_all(
-    async_get_ppm_versions(date = if (as.character(date) == "latest") NULL else date),
+    ppm_snapshots(),
     if (binaries) {
       async_get_ppm_status(
         distribution = current$distribution,
@@ -242,16 +239,10 @@ repo_sugar_ppm <- function(x, nm) {
   if (as.character(date) == "latest") {
     ver <- "latest"
   } else {
-    vers <- pkgenv$ppm_versions
-    ppm_dates <- names(vers)
-    if (date < ppm_dates[1]) {
-      stop("PPM snapshots go back to ", as.Date(ppm_dates[1]), " only")
+    if (date < "2017-10-10") {
+      stop("PPM snapshots go back to 2017-10-10 only")
     }
-    sel <- which(date <= ppm_dates)[1]
-    if (is.na(sel)) {
-      stop("Cannot find matching PPM snapshot for ", date)
-    }
-    ver <- vers[[sel]]
+    ver <- as.character(date)
   }
 
   # create repo URL
@@ -378,6 +369,9 @@ next_day <- function(x) {
 #'   release of `<version>` of `<package>`.
 #' - `PPM@R-<version>` PPM snapshot, for the day after R `<version>`
 #'   was released.
+#'
+#' Still works for dates starting from 2017-10-10, but now deprecated,
+#' because MRAN is discontinued:
 #' - `MRAN@<date>`, MRAN (Microsoft R Application Network) snapshot, at
 #'   the specified date.
 #' - `MRAN@<package>-<version>` MRAN snapshot, for the
@@ -385,20 +379,21 @@ next_day <- function(x) {
 #' - `MRAN@R-<version>` MRAN snapshot, for the day
 #'   after R `<version>` was released.
 #'
-#'
 #' Notes:
 #' * See more about PPM at <https://packagemanager.posit.co/client/#/>.
 #' * The `RSPM@` prefix is still supported and treated the same way as
 #'   `PPM@`.
-#' * See more about MRAN snapshots at
-#'   <https://mran.microsoft.com/timemachine>.
+#' * The MRAN service is now retired, see
+#'   <https://techcommunity.microsoft.com/t5/azure-sql-blog/microsoft-r-application-network-retirement/ba-p/3707161>
+#'   for details.
+#' * `MRAN@...` repository specifications now resolve to PPM, but note that
+#'   PPM snapshots are only available from 2017-10-10. See more about this
+#'   at <https://posit.co/blog/migrating-from-mran-to-posit-package-manager/>.
 #' * All dates (or times) can be specified in the ISO 8601 format.
 #' * If PPM does not have a snapshot available for a date, the next
 #'   available date is used.
 #' * Dates that are before the first, or after the last PPM snapshot
 #'   will trigger an error.
-#' * Dates before the first, or after the last MRAN snapshot will trigger
-#'   an error.
 #' * Unknown R or package versions will trigger an error.
 #'
 NULL
