@@ -1,5 +1,5 @@
 
-test_that("invalid PACKAGES file warns", {
+test_that("invalid PACKAGES file errors", {
   pri <- test_temp_dir()
   rep <- test_temp_dir()
 
@@ -14,9 +14,8 @@ test_that("invalid PACKAGES file warns", {
     writeBin(charToRaw("nope"), pgz)
   }
 
-  expect_error(
-    expect_warning(
-      get_private(cmc)$update_replica_rds(),
-      "Cannot read metadata information"),
-    "No metadata available")
+  expect_snapshot(
+    error = TRUE,
+    suppressMessages(get_private(cmc)$update_replica_rds())
+  )
 })
